HUMAN_CLICK_LATENCY = (0.1, 0.3)
HUMAN_MOUSE_MOVE_LATENCY = (0.01, 0.03)
HUMAN_FOCUS_ELEMENT_LATENCY = (0.1, 0.6)
HUMAN_OBSERVE_VIEW_LATENCY = (0.5, 1.0)
HUMAN_OBSERVE_PAGE_LATENCY = (2.0, 5.0)
HUMAN_SCROLL_LATENCY = (0.1, 0.7)
